diff --git a/src/app.tsx b/src/app.tsx
index 599aa91f..81a67d78 100644
--- a/src/app.tsx
+++ b/src/app.tsx
@@ -33,8 +33,10 @@ const BoardLayout = () => {
return ;
}
- // force rerender of post form when navigating between pages
- const key = `${subplebbitAddress}-${location.pathname}`;
+ // force rerender of post form when navigating between pages, except when opening settings modal in current view
+ const key = location.pathname.endsWith('/settings')
+ ? `${subplebbitAddress}-${location.pathname.replace(/\/settings$/, '')}`
+ : `${subplebbitAddress}-${location.pathname}`;
return (